@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -35,7 +35,6 @@ abstract class AbstractSessionArrayStorage implements
         $this->init($input);
     }
 
-
     /**
      * Initialize Storage
      *
@@ -351,9 +350,9 @@ abstract class AbstractSessionArrayStorage implements
     public function setMetadata($key, $value, $overwriteArray = false)
     {
         if ($this->isImmutable()) {
-            throw new Exception\RuntimeException(sprintf(
-                'Cannot set key "%s" as storage is marked isImmutable', $key
-            ));
+            throw new Exception\RuntimeException(
+                sprintf('Cannot set key "%s" as storage is marked isImmutable', $key)
+            );
         }
 
         if (!isset($_SESSION['__ZF'])) {
