@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 namespace Zend\Test\PHPUnit\Controller;
@@ -381,7 +381,11 @@ abstract class AbstractHttpControllerTestCase extends AbstractControllerTestCase
             $document->registerXpathNamespaces($this->xpathNamespaces);
         }
 
-        $result   = Document\Query::execute($path, $document, $useXpath ? Document\Query::TYPE_XPATH : Document\Query::TYPE_CSS);
+        $result = Document\Query::execute(
+            $path,
+            $document,
+            $useXpath ? Document\Query::TYPE_XPATH : Document\Query::TYPE_CSS
+        );
 
         return $result;
     }
